package gorm_model

import (
	"time"
)

type YounggeeLocalLifeInfo struct {
	Id                  int64     `gorm:"column:id;primary_key;AUTO_INCREMENT"`             // 本地生活表主键ID
	LocalId             string    `gorm:"column:local_id;NOT NULL"`                         // 项目id
	LocalType           int       `gorm:"column:local_type"`                                // 项目类型，1代表公开项目，2代表定向项目
	LocalPlatform       int       `gorm:"column:local_platform"`                            // 项目平台，1-7分别代表小红书、抖音、微博、快手、b站、大众点评、知乎
	ServiceChargeRate   string    `gorm:"column:service_charge_rate;default:0.00;NOT NULL"` // 公开服务费率
	StoreId             int       `gorm:"column:store_id"`                                  // 关联门店id
	StoreRelatedAt      time.Time `gorm:"column:store_related_at"`                          // 关联门店时间
	TeamBuyingId        int       `gorm:"column:team_buying_id"`                            // 关联团购id
	TeamBuyingRelatedAt time.Time `gorm:"column:team_buying_related_at"`                    // 关联团购时间
	PromoteBody         int       `gorm:"column:promote_body"`                              // 推广主体（1门店 2团购）
	Donate              int       `gorm:"column:donate"`                                    // 赠送达人套餐（1有赠送 2无赠送）
	LocalName           string    `gorm:"column:local_name"`                                // 任务标题
	TalentType          string    `gorm:"column:talent_type"`                               // 达人类型（,分隔）
	RecruitDdl          time.Time `gorm:"column:recruit_ddl"`                               // 招募截止时间
	TaskForm            int       `gorm:"column:task_form"`                                 // 任务形式，1-2分别代表线下探店,素材分发
	ContentType         int       `gorm:"column:content_type"`                              // 内容形式，1代表图文，2代表视频
	TaskDetail          string    `gorm:"column:task_detail"`                               // 任务详情
	TaskStatus          int       `gorm:"column:task_status"`                               // 项目状态，1-10分别代表创建中、待审核、审核通过、招募中、招募完毕、待支付、已支付、执行中、失效、已结案
	EnterpriseId        string    `gorm:"column:enterprise_id"`                             // 所属企业id
	SubAccountId        int       `gorm:"column:sub_account_id;default:0;NOT NULL"`         // 子账号id
	OperatorType        int       `gorm:"column:operator_type"`                             // 创建者类型，1商家主账号，2商家子账号
	ApplyNum            int       `gorm:"column:apply_num;default:0;NOT NULL"`              // 报名人数
	RecruitNum          int       `gorm:"column:recruit_num;default:0;NOT NULL"`            // 已招募人数
	SettleNum           int       `gorm:"column:settle_num;default:0"`                      // 结案人数
	CreatedAt           time.Time `gorm:"column:created_at"`                                // 创建时间
	UpdatedAt           time.Time `gorm:"column:updated_at"`                                // 修改时间
	AutoFailAt          time.Time `gorm:"column:auto_fail_at"`                              // 失效自动处理时间
	AutoTaskId          int       `gorm:"column:auto_task_id;default:0;NOT NULL"`           // 定时任务id
	AutoDefaultId       int       `gorm:"column:auto_default_id;default:0;NOT NULL"`        // 违约状态id
	FailReason          int       `gorm:"column:fail_reason"`                               // 失效原因，1、2分别表示逾期未支付、项目存在风险
	PaymentAmount       string    `gorm:"column:payment_amount"`                            // 支付金额
	PayAt               time.Time `gorm:"column:pay_at"`                                    // 支付时间
	SubmitAt            time.Time `gorm:"column:submit_at"`                                 // 提交审核时间
	PassAt              time.Time `gorm:"column:pass_at"`                                   // 审核通过时间
	FinishAt            time.Time `gorm:"column:finish_at"`                                 // 结案时间
	EstimatedCost       string    `gorm:"column:estimated_cost"`                            // 预估成本
	SettlementAmount    string    `gorm:"column:settlement_amount"`                         // 结算金额
	TotalRecruitNum     int       `gorm:"column:total_recruit_num"`                         // 此任务各策略招募人数总和
	Tools               string    `gorm:"column:tools;NOT NULL"`                            // 工具选择，1邀约招募 2探店邀约 3审稿工具 4作品审查 5数据巡检 6结算账单（,分隔）
	NeedReview          int       `gorm:"column:need_review;default:0;NOT NULL"`            // 待审稿
	NeedQuality         int       `gorm:"column:need_quality;default:0;NOT NULL"`           // 待质检
	NeedCalculate       int       `gorm:"column:need_calculate;default:0;NOT NULL"`         // 待结算
	NeedReserve         int       `gorm:"column:need_reserve;default:0;NOT NULL"`           // 待预约
	NeedConfirm         int       `gorm:"column:need_confirm;default:0;NOT NULL"`           // 待确认
	NeedExplore         int       `gorm:"column:need_explore;default:0;NOT NULL"`           // 待探店
	ExploredNum         int       `gorm:"column:explored_num;default:0;NOT NULL"`           // 已探店
	InvoiceStatus       int       `gorm:"column:invoice_status;default:0;NOT NULL"`         // 开票状态（1开票中 2已开票）
}

func (m *YounggeeLocalLifeInfo) TableName() string {
	return "younggee_local_life_info"
}
