package gorm_model

import "time"

type SProjectInfo struct {
	SProjectId          int        `gorm:"column:s_project_id;primary_key;AUTO_INCREMENT"` // 服务商加入商单后的种草任务ID
	ProjectId           string     `gorm:"column:project_id;"`                             // 被服务商加入商单的原种草任务ID
	ProjectType         int        `gorm:"column:project_type"`                            // 种草任务类型，1为公开，2为定向
	ProductId           int64      `gorm:"column:product_id;"`                             // 商品ID
	ProjectName         string     `gorm:"column:project_name"`                            // 种草任务名称
	ProjectStatus       int64      `gorm:"column:project_status"`                          // 种草任务状态
	ProjectPlatform     int64      `gorm:"column:project_platform"`                        // 种草任务平台，1-7分别代表小红书、抖音、微博、快手、b站、大众点评、知乎
	ProjectForm         int64      `gorm:"column:project_form"`                            // 任务形式，1-3分别代表商品寄拍、素材分发、虚拟产品测评
	ContentType         int64      `gorm:"column:content_type"`                            // 内容形式，1代表图文，2代表视频
	ShareCode           string     `gorm:"column:share_code"`                              // 分享码URL
	ApplyNum            int        `gorm:"column:apply_num;default:0;NOT NULL"`            // 报名人数
	RecruitNum          int        `gorm:"column:recruit_num;default:0;NOT NULL"`          // 已招募人数
	QuitNum             int        `gorm:"column:quit_num;default:0;NOT NULL"`             // 解约人数
	SettleNum           int        `gorm:"column:settle_num;default:0;NOT NULL"`           // 已结算人数
	EnterpriseId        string     `gorm:"column:enterprise_id"`                           // 所属企业ID
	SupplierId          int        `gorm:"column:supplier_id"`                             // 所属服务商ID
	SubAccountId        int        `gorm:"column:sub_account_id"`                          // 所属子账号ID
	ServiceCharge       float64    `gorm:"column:service_charge"`                          // 服务商预估可赚服务费
	ServiceChargeActual float64    `gorm:"column:service_charge_actual"`                   // 服务商实际可赚服务费
	ServiceChargeSettle float64    `gorm:"column:service_charge_settle"`                   // 服务商已结算服务费
	OperatorType        int        `gorm:"column:operator_type"`                           // 添加商单操作人类型，1为服务商主账号，2为服务商子账号
	SProjectStatus      int        `gorm:"column:s_project_status"`                        // 服务商种草任务状态，1待确认，2已确认，3已拒绝
	StrategyStatus      int        `gorm:"column:strategy_status"`                         // 定向种草任务是否替换招募策略
	CreateStrategyId    int        `gorm:"column:create_strategy_id"`                      // 服务商修改服务费操作人ID
	CreateStrategyType  int        `gorm:"column:create_strategy_type"`                    // 服务商修改服务费操作人类型：1服务商主账号，2子账号
	CreateTime          *time.Time `gorm:"column:create_time"`                             // 创建时间
}

func (m *SProjectInfo) TableName() string {
	return "younggee_s_project_info"
}
