package http_model

type SProjectListRequest struct {
	SProjectId      int    `json:"s_project_id"`     // 加入商单的种草任务ID
	ProjectId       string `json:"project_id"`       // 种草任务ID
	ProjectType     int    `json:"project_type"`     // 种草任务类型，1为公开，2为定向
	ProjectName     string `json:"project_name"`     // 种草任务名称
	ProjectPlatform int    `json:"project_platform"` // 种草任务平台，1-7分别代表小红书、抖音、微博、快手、b站、大众点评、知乎
	ProjectForm     int    `json:"project_form"`     // 任务形式，1-3分别代表商品寄拍、素材分发、虚拟产品测评
	ContentType     int    `json:"content_type"`     // 内容形式，1代表图文，2代表视频
	SupplierId      int    `json:"supplier_id"`      // 服务商ID
	ProjectStatus   int    `json:"project_status"`   // 种草任务状态
	PageNum         int32  `json:"page_num"`
	PageSize        int32  `json:"page_size"`
}

type SProjectListReview struct {
	SProjectId          int     `json:"s_project_id"`          // 服务商加入商单后的种草任务ID
	ProjectId           string  `json:"project_id"`            // 被服务商加入商单的原种草任务ID
	ProjectType         int64   `json:"project_type"`          // 种草任务类型，1为公开，2为定向
	ProjectName         string  `json:"project_name"`          // 种草任务名称
	ProjectPlatform     int64   `json:"project_platform"`      // 种草任务平台，1-7分别代表小红书、抖音、微博、快手、b站、大众点评、知乎
	ProjectForm         int64   `json:"project_form"`          // 任务形式，1-3分别代表商品寄拍、素材分发、虚拟产品测评
	ContentType         int64   `json:"content_type"`          // 内容形式，1代表图文，2代表视频
	ProjectStatus       int64   `json:"project_status"`        // 种草任务状态
	ShareCode           string  `json:"share_code"`            // 分享码URL
	ApplyNum            int     `json:"apply_num"`             // 报名人数
	RecruitNum          int     `json:"recruit_num"`           // 已招募人数
	SettleNum           int     `json:"settle_num"`            // 已结算人数
	EnterpriseId        string  `json:"enterprise_id"`         // 所属企业ID
	SupplierId          int     `json:"supplier_id"`           // 所属服务商ID
	SubAccountId        int     `json:"sub_account_id"`        // 所属子账号ID
	ServiceCharge       float64 `json:"service_charge"`        // 服务商预估可赚服务费
	ServiceChargeActual float64 `json:"service_charge_actual"` // 服务商实际可赚服务费
	ServiceChargeSettle float64 `json:"service_charge_settle"` // 已结算服务费
	OperatorType        int     `json:"operator_type"`         // 添加商单操作人类型，1为服务商主账号，2为服务商子账号
	SProjectStatus      int     `json:"s_project_status"`      // 服务商种草任务状态，1待确认，2已确认，3已拒绝
	StrategyStatus      int     `json:"strategy_status"`       // 定向种草任务是否替换招募策略
	CreateStrategyId    int     `json:"create_strategy_id"`    // 服务商修改服务费操作人ID
	CreateStrategyType  int     `json:"create_strategy_type"`  // 服务商修改服务费操作人类型：1服务商主账号，2子账号
	CreateTime          string  `json:"create_time"`           // 创建时间
	ProductPhotoUrl     string  `json:"product_photo_url"`     // 商品主图URL
	ProductPhotoSymbol  int64   `json:"product_photo_symbol"`  // 标志位
	ProductPhotoUid     string  `json:"product_photo_uid"`     // uid
	ProductName         string  `json:"product_name"`          // 商品名称
	ProductId           int64   `json:"product_id"`            // 商品ID
	ProductPrice        float64 `json:"product_price"`         // 商品售价
}

type SProjectData struct {
	SProjectList []*SProjectListReview `json:"s_project_info"` // 服务商加入商单的种草任务信息
	Total        int64                 `json:"total"`          // 数量
}

func NewSProjectListRequest() *SProjectListRequest {
	return new(SProjectListRequest)
}

func NewSProjectListResponse() *CommonResponse {
	resp := new(CommonResponse)
	resp.Data = new(SProjectData)
	return resp
}
