package http_model

import "time"

type SpecialProjectListRequest struct {
	PageSize           int32  `json:"page_size"`
	PageNum            int32  `json:"page_num"`
	ProjectName        string `json:"project_name"`         // 项目名
	ProjectType        int    `json:"project_type"`         // 种草任务类型，1为公开，2为定向
	ProjectStatus      int    `json:"project_status"`       // 种草任务状态，1-10分别代表创建中、待审核、审核通过、招募中、招募完毕、待支付、已支付、失效、执行中、已结案
	ProjectPlatform    string `json:"project_platform"`     // 种草任务平台
	ProjectForm        string `json:"project_form"`         // 种草任务形式
	ProjectContentType string `json:"project_content_type"` // 种草任务内容形式
	SProjectStatus     int    `json:"s_project_status"`     // 服务商种草任务状态，1待确认，2已确认，3已拒绝
	SupplierId         int    `json:"supplier_id"`          // 服务商ID
}

type SpecialProjectListData struct {
	SpecialProjectInfo []*SpecialProjectResponse `json:"special_project_info"`
	Total              int64                     `json:"total"`
}

type SpecialProjectResponse struct {
	SProjectId         int                   `json:"s_project_id"`         // 服务商加入商单后的种草任务ID
	ProjectPlatform    int64                 `json:"project_platform"`     // 种草任务平台，1-7分别代表小红书、抖音、微博、快手、b站、大众点评、知乎
	ProjectForm        int64                 `json:"project_form"`         // 任务形式，1-3分别代表商品寄拍、素材分发、虚拟产品测评
	ContentType        int64                 `json:"content_type"`         // 内容形式，1代表图文，2代表视频
	SProjectStatus     int                   `json:"s_project_status"`     // 服务商种草任务状态，1待确认，2已确认，3已拒绝
	CreateTime         *time.Time            `json:"create_time"`          // 创建时间
	RecruitStrategy    []EasyRecruitStrategy `json:"recruit_strategy"`     // 招募策略
	ProductPhotoUrl    string                `json:"product_photo_url"`    // 商品主图URL
	ProductPhotoSymbol int64                 `json:"product_photo_symbol"` // 标志位
	ProductPhotoUid    string                `json:"product_photo_uid"`    // uid
	ProductName        string                `json:"product_name"`         // 商品名称
	ProductId          int64                 `json:"product_id"`           // 商品ID
	ProductPrice       float64               `json:"product_price"`        // 商品售价
	Tools              string                `json:"tools"`                // 工具选择，1邀约招募 2样品物流 3审稿工具 4作品审查 5数据巡检 6结算账单（,分隔）
}

func NewSpecialProjectListRequest() *SpecialProjectListRequest {
	return new(SpecialProjectListRequest)
}
func NewSpecialProjectListResponse() *CommonResponse {
	resp := new(CommonResponse)
	resp.Data = new(SpecialProjectListData)
	return resp
}
